pub struct GoogleChromeManagementV1BootPerformanceReport {
pub boot_up_duration: Option<Duration>,
pub boot_up_time: Option<DateTime<Utc>>,
pub report_time: Option<DateTime<Utc>>,
pub shutdown_duration: Option<Duration>,
pub shutdown_reason: Option<String>,
pub shutdown_time: Option<DateTime<Utc>>,
}Expand description
Boot performance report of a device. * This field is telemetry information and this will change over time as the device is utilized. * Data for this field is controlled via policy: ReportDeviceBootMode * Data Collection Frequency: On every boot up event * Default Data Reporting Frequency: 3 hours - Policy Controlled: Yes * Cache: If the device is offline, the collected data is stored locally, and will be reported when the device is next online: Yes * Reported for affiliated users only: N/A * Granular permission needed: TELEMETRY_API_OS_REPORT
This type is not used in any activity, and only used as part of another schema.
Fields
boot_up_duration: Option<Duration>Total time to boot up.
boot_up_time: Option<DateTime<Utc>>The timestamp when power came on.
report_time: Option<DateTime<Utc>>Timestamp when the report was collected.
shutdown_duration: Option<Duration>Total time since shutdown start to power off.
shutdown_reason: Option<String>The shutdown reason.
shutdown_time: Option<DateTime<Utc>>The timestamp when shutdown.