pub struct GoogleChromeManagementV1TelemetryEventNotificationFilter {
pub event_types: Option<Vec<String>>,
}Expand description
Configures how the telemetry events should be filtered.
This type is not used in any activity, and only used as part of another schema.
Fields
event_types: Option<Vec<String>>Only sends the notifications for events of these types. Must not be empty.