pub struct GoogleChromeManagementV1TelemetryNotificationFilter {
pub device_id: Option<String>,
pub device_org_unit_id: Option<String>,
pub telemetry_event_notification_filter: Option<GoogleChromeManagementV1TelemetryEventNotificationFilter>,
pub user_email: Option<String>,
pub user_org_unit_id: Option<String>,
}Expand description
Configures how the telemetry data should be filtered.
This type is not used in any activity, and only used as part of another schema.
Fields
device_id: Option<String>If set, only sends notifications for telemetry data coming from this device.
device_org_unit_id: Option<String>If set, only sends notifications for telemetry data coming from devices in this org unit.
telemetry_event_notification_filter: Option<GoogleChromeManagementV1TelemetryEventNotificationFilter>Only sends notifications for the telemetry events matching this filter.
user_email: Option<String>If set, only sends notifications for telemetry data coming from devices owned by this user.
user_org_unit_id: Option<String>If set, only sends notifications for telemetry data coming from devices owned by users in this org unit.