pub struct GoogleChromeManagementV1TotalMemoryEncryptionInfo {
pub encryption_algorithm: Option<String>,
pub encryption_state: Option<String>,
pub key_length: Option<i64>,
pub max_keys: Option<i64>,
}Expand description
Memory encryption information of a device. * This field provides device information, which is static and will not change over time. * Data for this field is controlled via policy: ReportDeviceMemoryInfo * Data Collection Frequency: At device startup * Default Data Reporting Frequency: At device startup - Policy Controlled: Yes * Cache: If the device is offline, the collected data is stored locally, and will be reported when the device is next online: Yes * Reported for affiliated users only: N/A
This type is not used in any activity, and only used as part of another schema.
Fields
encryption_algorithm: Option<String>Memory encryption algorithm.
encryption_state: Option<String>The state of memory encryption on the device.
key_length: Option<i64>The length of the encryption keys.
max_keys: Option<i64>The maximum number of keys that can be used for encryption.