pub struct CustomerMethods<'a, C>where
C: 'a,{ /* private fields */ }Expand description
A builder providing access to all methods supported on customer resources.
It is not used directly, but through the ChromeManagement hub.
Example
Instantiate a resource builder
extern crate hyper;
extern crate hyper_rustls;
extern crate google_chromemanagement1 as chromemanagement1;
use chromemanagement1::{ChromeManagement, FieldMask, hyper_rustls, hyper_util, yup_oauth2};
let secret: yup_oauth2::ApplicationSecret = Default::default();
let connector = hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_only()
.enable_http2()
.build();
let executor = hyper_util::rt::TokioExecutor::new();
let auth = yup_oauth2::InstalledFlowAuthenticator::with_client(
secret,
yup_oauth2::InstalledFlowReturnMethod::HTTPRedirect,
yup_oauth2::client::CustomHyperClientBuilder::from(
hyper_util::client::legacy::Client::builder(executor).build(connector),
),
).build().await.unwrap();
let client = hyper_util::client::legacy::Client::builder(
hyper_util::rt::TokioExecutor::new()
)
.build(
hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_or_http()
.enable_http2()
.build()
);
let mut hub = ChromeManagement::new(client, auth);
// Usually you wouldn't bind this to a variable, but keep calling *CallBuilders*
// like `apps_android_get(...)`, `apps_chrome_get(...)`, `apps_count_chrome_app_requests(...)`, `apps_fetch_devices_requesting_extension(...)`, `apps_fetch_users_requesting_extension(...)`, `apps_web_get(...)`, `certificate_provisioning_processes_claim(...)`, `certificate_provisioning_processes_get(...)`, `certificate_provisioning_processes_operations_get(...)`, `certificate_provisioning_processes_set_failure(...)`, `certificate_provisioning_processes_sign_data(...)`, `certificate_provisioning_processes_upload_certificate(...)`, `profiles_commands_create(...)`, `profiles_commands_get(...)`, `profiles_commands_list(...)`, `profiles_delete(...)`, `profiles_get(...)`, `profiles_list(...)`, `reports_count_active_devices(...)`, `reports_count_chrome_browsers_needing_attention(...)`, `reports_count_chrome_crash_events(...)`, `reports_count_chrome_devices_reaching_auto_expiration_date(...)`, `reports_count_chrome_devices_that_need_attention(...)`, `reports_count_chrome_hardware_fleet_devices(...)`, `reports_count_chrome_versions(...)`, `reports_count_devices_per_boot_type(...)`, `reports_count_devices_per_release_channel(...)`, `reports_count_installed_apps(...)`, `reports_count_print_jobs_by_printer(...)`, `reports_count_print_jobs_by_user(...)`, `reports_enumerate_print_jobs(...)`, `reports_find_installed_app_devices(...)`, `telemetry_devices_get(...)`, `telemetry_devices_list(...)`, `telemetry_events_list(...)`, `telemetry_notification_configs_create(...)`, `telemetry_notification_configs_delete(...)`, `telemetry_notification_configs_list(...)`, `telemetry_users_get(...)`, `telemetry_users_list(...)` and `third_party_profile_users_move(...)`
// to build up your call.
let rb = hub.customers();Implementations
Sourceimpl<'a, C> CustomerMethods<'a, C>
impl<'a, C> CustomerMethods<'a, C>
Sourcepub fn apps_android_get(&self, name: &str) -> CustomerAppAndroidGetCall<'a, C>
pub fn apps_android_get(&self, name: &str) -> CustomerAppAndroidGetCall<'a, C>
Create a builder to help you perform the following task:
Get a specific app for a customer by its resource name.
Arguments
name- Required. The app for which details are being queried. Examples: “customers/my_customer/apps/chrome/gmbmikajjgmnabiglmofipeabaddhgne@2.1.2” for the Save to Google Drive Chrome extension version 2.1.2, “customers/my_customer/apps/android/com.google.android.apps.docs” for the Google Drive Android app’s latest version.
Sourcepub fn apps_chrome_get(&self, name: &str) -> CustomerAppChromeGetCall<'a, C>
pub fn apps_chrome_get(&self, name: &str) -> CustomerAppChromeGetCall<'a, C>
Create a builder to help you perform the following task:
Get a specific app for a customer by its resource name.
Arguments
name- Required. The app for which details are being queried. Examples: “customers/my_customer/apps/chrome/gmbmikajjgmnabiglmofipeabaddhgne@2.1.2” for the Save to Google Drive Chrome extension version 2.1.2, “customers/my_customer/apps/android/com.google.android.apps.docs” for the Google Drive Android app’s latest version.
Sourcepub fn apps_web_get(&self, name: &str) -> CustomerAppWebGetCall<'a, C>
pub fn apps_web_get(&self, name: &str) -> CustomerAppWebGetCall<'a, C>
Create a builder to help you perform the following task:
Get a specific app for a customer by its resource name.
Arguments
name- Required. The app for which details are being queried. Examples: “customers/my_customer/apps/chrome/gmbmikajjgmnabiglmofipeabaddhgne@2.1.2” for the Save to Google Drive Chrome extension version 2.1.2, “customers/my_customer/apps/android/com.google.android.apps.docs” for the Google Drive Android app’s latest version.
Sourcepub fn apps_count_chrome_app_requests(
&self,
customer: &str,
) -> CustomerAppCountChromeAppRequestCall<'a, C>
pub fn apps_count_chrome_app_requests( &self, customer: &str, ) -> CustomerAppCountChromeAppRequestCall<'a, C>
Create a builder to help you perform the following task:
Generate summary of app installation requests.
Arguments
customer- Required. Customer id or “my_customer” to use the customer associated to the account making the request.
Sourcepub fn apps_fetch_devices_requesting_extension(
&self,
customer: &str,
) -> CustomerAppFetchDevicesRequestingExtensionCall<'a, C>
pub fn apps_fetch_devices_requesting_extension( &self, customer: &str, ) -> CustomerAppFetchDevicesRequestingExtensionCall<'a, C>
Create a builder to help you perform the following task:
Get a list of devices that have requested to install an extension.
Arguments
customer- Required. The customer ID or “my_customer” prefixed with “customers/”.
Sourcepub fn apps_fetch_users_requesting_extension(
&self,
customer: &str,
) -> CustomerAppFetchUsersRequestingExtensionCall<'a, C>
pub fn apps_fetch_users_requesting_extension( &self, customer: &str, ) -> CustomerAppFetchUsersRequestingExtensionCall<'a, C>
Create a builder to help you perform the following task:
Get a list of users that have requested to install an extension.
Arguments
customer- Required. The customer ID or “my_customer” prefixed with “customers/”.
Sourcepub fn certificate_provisioning_processes_operations_get(
&self,
name: &str,
) -> CustomerCertificateProvisioningProcessOperationGetCall<'a, C>
pub fn certificate_provisioning_processes_operations_get( &self, name: &str, ) -> CustomerCertificateProvisioningProcessOperationGetCall<'a, C>
Create a builder to help you perform the following task:
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
Arguments
name- The name of the operation resource.
Sourcepub fn certificate_provisioning_processes_claim(
&self,
request: GoogleChromeManagementVersionsV1ClaimCertificateProvisioningProcessRequest,
name: &str,
) -> CustomerCertificateProvisioningProcessClaimCall<'a, C>
pub fn certificate_provisioning_processes_claim( &self, request: GoogleChromeManagementVersionsV1ClaimCertificateProvisioningProcessRequest, name: &str, ) -> CustomerCertificateProvisioningProcessClaimCall<'a, C>
Create a builder to help you perform the following task:
Claims a certificate provisioning process. For each certificate provisioning process, this operation can succeed only for one caller_instance_id.
Arguments
request- No description provided.name- Required. Resource name of theCertificateProvisioningProcessto claim. The name pattern is given ascustomers/{customer}/certificateProvisioningProcesses/{certificate_provisioning_process}with{customer}being the obfuscated customer id and{certificate_provisioning_process}being the certificate provisioning process id.
Sourcepub fn certificate_provisioning_processes_get(
&self,
name: &str,
) -> CustomerCertificateProvisioningProcessGetCall<'a, C>
pub fn certificate_provisioning_processes_get( &self, name: &str, ) -> CustomerCertificateProvisioningProcessGetCall<'a, C>
Create a builder to help you perform the following task:
Retrieves a certificate provisioning process.
Arguments
name- Required. Resource name of theCertificateProvisioningProcessto return. The name pattern is given ascustomers/{customer}/certificateProvisioningProcesses/{certificate_provisioning_process}with{customer}being the obfuscated customer id and{certificate_provisioning_process}being the certificate provisioning process id.
Sourcepub fn certificate_provisioning_processes_set_failure(
&self,
request: GoogleChromeManagementVersionsV1SetFailureRequest,
name: &str,
) -> CustomerCertificateProvisioningProcessSetFailureCall<'a, C>
pub fn certificate_provisioning_processes_set_failure( &self, request: GoogleChromeManagementVersionsV1SetFailureRequest, name: &str, ) -> CustomerCertificateProvisioningProcessSetFailureCall<'a, C>
Create a builder to help you perform the following task:
Marks a certificate provisioning process as failed.
Arguments
request- No description provided.name- Required. Resource name of theCertificateProvisioningProcessto return. The name pattern is given ascustomers/{customer}/certificateProvisioningProcesses/{certificate_provisioning_process}with{customer}being the obfuscated customer id and{certificate_provisioning_process}being the certificate provisioning process id.
Sourcepub fn certificate_provisioning_processes_sign_data(
&self,
request: GoogleChromeManagementVersionsV1SignDataRequest,
name: &str,
) -> CustomerCertificateProvisioningProcessSignDataCall<'a, C>
pub fn certificate_provisioning_processes_sign_data( &self, request: GoogleChromeManagementVersionsV1SignDataRequest, name: &str, ) -> CustomerCertificateProvisioningProcessSignDataCall<'a, C>
Create a builder to help you perform the following task:
Requests the client that initiated a certificate provisioning process to sign data. This should only be called after ClaimCertificateProvisioningProcess has been successfully executed.
Arguments
request- No description provided.name- Required. Resource name of theCertificateProvisioningProcessto return. The name pattern is given ascustomers/{customer}/certificateProvisioningProcesses/{certificate_provisioning_process}with{customer}being the obfuscated customer id and{certificate_provisioning_process}being the certificate provisioning process id.
Sourcepub fn certificate_provisioning_processes_upload_certificate(
&self,
request: GoogleChromeManagementVersionsV1UploadCertificateRequest,
name: &str,
) -> CustomerCertificateProvisioningProcessUploadCertificateCall<'a, C>
pub fn certificate_provisioning_processes_upload_certificate( &self, request: GoogleChromeManagementVersionsV1UploadCertificateRequest, name: &str, ) -> CustomerCertificateProvisioningProcessUploadCertificateCall<'a, C>
Create a builder to help you perform the following task:
Uploads a successfully issued certificate for a certificate provisioning process.
Arguments
request- No description provided.name- Required. Resource name of theCertificateProvisioningProcessto return. The name pattern is given ascustomers/{customer}/certificateProvisioningProcesses/{certificate_provisioning_process}with{customer}being the obfuscated customer id and{certificate_provisioning_process}being the certificate provisioning process id.
Sourcepub fn profiles_commands_create(
&self,
request: GoogleChromeManagementVersionsV1ChromeBrowserProfileCommand,
parent: &str,
) -> CustomerProfileCommandCreateCall<'a, C>
pub fn profiles_commands_create( &self, request: GoogleChromeManagementVersionsV1ChromeBrowserProfileCommand, parent: &str, ) -> CustomerProfileCommandCreateCall<'a, C>
Create a builder to help you perform the following task:
Creates a Chrome browser profile remote command.
Arguments
request- No description provided.parent- Required. Format: customers/{customer_id}/profiles/{profile_permanent_id}
Sourcepub fn profiles_commands_get(
&self,
name: &str,
) -> CustomerProfileCommandGetCall<'a, C>
pub fn profiles_commands_get( &self, name: &str, ) -> CustomerProfileCommandGetCall<'a, C>
Create a builder to help you perform the following task:
Gets a Chrome browser profile remote command.
Arguments
name- Required. Format: customers/{customer_id}/profiles/{profile_permanent_id}/commands/{command_id}
Sourcepub fn profiles_commands_list(
&self,
parent: &str,
) -> CustomerProfileCommandListCall<'a, C>
pub fn profiles_commands_list( &self, parent: &str, ) -> CustomerProfileCommandListCall<'a, C>
Create a builder to help you perform the following task:
Lists remote commands of a Chrome browser profile.
Arguments
parent- Required. Format: customers/{customer_id}/profiles/{profile_permanent_id}
Sourcepub fn profiles_delete(&self, name: &str) -> CustomerProfileDeleteCall<'a, C>
pub fn profiles_delete(&self, name: &str) -> CustomerProfileDeleteCall<'a, C>
Create a builder to help you perform the following task:
Deletes the data collected from a Chrome browser profile.
Arguments
name- Required. Format: customers/{customer_id}/profiles/{profile_permanent_id}
Sourcepub fn profiles_get(&self, name: &str) -> CustomerProfileGetCall<'a, C>
pub fn profiles_get(&self, name: &str) -> CustomerProfileGetCall<'a, C>
Create a builder to help you perform the following task:
Gets a Chrome browser profile with customer ID and profile permanent ID.
Arguments
name- Required. Format: customers/{customer_id}/profiles/{profile_permanent_id}
Sourcepub fn profiles_list(&self, parent: &str) -> CustomerProfileListCall<'a, C>
pub fn profiles_list(&self, parent: &str) -> CustomerProfileListCall<'a, C>
Create a builder to help you perform the following task:
Lists Chrome browser profiles of a customer based on the given search and sorting criteria.
Arguments
parent- Required. Format: customers/{customer_id}
Sourcepub fn reports_count_active_devices(
&self,
customer: &str,
) -> CustomerReportCountActiveDeviceCall<'a, C>
pub fn reports_count_active_devices( &self, customer: &str, ) -> CustomerReportCountActiveDeviceCall<'a, C>
Create a builder to help you perform the following task:
Get a count of active devices per set time frames.
Arguments
customer- Required. Obfuscated customer ID prefixed with “customers/C” or “customers/my_customer”.
Sourcepub fn reports_count_chrome_browsers_needing_attention(
&self,
customer: &str,
) -> CustomerReportCountChromeBrowsersNeedingAttentionCall<'a, C>
pub fn reports_count_chrome_browsers_needing_attention( &self, customer: &str, ) -> CustomerReportCountChromeBrowsersNeedingAttentionCall<'a, C>
Create a builder to help you perform the following task:
Count of Chrome Browsers that have been recently enrolled, have new policy to be synced, or have no recent activity.
Arguments
customer- Required. The customer ID or “my_customer” prefixed with “customers/”.
Sourcepub fn reports_count_chrome_crash_events(
&self,
customer: &str,
) -> CustomerReportCountChromeCrashEventCall<'a, C>
pub fn reports_count_chrome_crash_events( &self, customer: &str, ) -> CustomerReportCountChromeCrashEventCall<'a, C>
Create a builder to help you perform the following task:
Get a count of Chrome crash events.
Arguments
customer- Customer ID.
Sourcepub fn reports_count_chrome_devices_reaching_auto_expiration_date(
&self,
customer: &str,
) -> CustomerReportCountChromeDevicesReachingAutoExpirationDateCall<'a, C>
pub fn reports_count_chrome_devices_reaching_auto_expiration_date( &self, customer: &str, ) -> CustomerReportCountChromeDevicesReachingAutoExpirationDateCall<'a, C>
Create a builder to help you perform the following task:
Generate report of the number of devices expiring in each month of the selected time frame. Devices are grouped by auto update expiration date and model. Further information can be found here.
Arguments
customer- Required. The customer ID or “my_customer” prefixed with “customers/”.
Sourcepub fn reports_count_chrome_devices_that_need_attention(
&self,
customer: &str,
) -> CustomerReportCountChromeDevicesThatNeedAttentionCall<'a, C>
pub fn reports_count_chrome_devices_that_need_attention( &self, customer: &str, ) -> CustomerReportCountChromeDevicesThatNeedAttentionCall<'a, C>
Create a builder to help you perform the following task:
Counts of ChromeOS devices that have not synced policies or have lacked user activity in the past 28 days, are out of date, or are not complaint. Further information can be found here https://support.google.com/chrome/a/answer/10564947
Arguments
customer- Required. The customer ID or “my_customer” prefixed with “customers/”.
Sourcepub fn reports_count_chrome_hardware_fleet_devices(
&self,
customer: &str,
) -> CustomerReportCountChromeHardwareFleetDeviceCall<'a, C>
pub fn reports_count_chrome_hardware_fleet_devices( &self, customer: &str, ) -> CustomerReportCountChromeHardwareFleetDeviceCall<'a, C>
Create a builder to help you perform the following task:
Counts of devices with a specific hardware specification from the requested hardware type (for example model name, processor type). Further information can be found here https://support.google.com/chrome/a/answer/10564947
Arguments
customer- Required. The customer ID or “my_customer”.
Sourcepub fn reports_count_chrome_versions(
&self,
customer: &str,
) -> CustomerReportCountChromeVersionCall<'a, C>
pub fn reports_count_chrome_versions( &self, customer: &str, ) -> CustomerReportCountChromeVersionCall<'a, C>
Create a builder to help you perform the following task:
Generate report of installed Chrome versions.
Arguments
customer- Required. Customer id or “my_customer” to use the customer associated to the account making the request.
Sourcepub fn reports_count_devices_per_boot_type(
&self,
customer: &str,
) -> CustomerReportCountDevicesPerBootTypeCall<'a, C>
pub fn reports_count_devices_per_boot_type( &self, customer: &str, ) -> CustomerReportCountDevicesPerBootTypeCall<'a, C>
Create a builder to help you perform the following task:
Get a count of devices per boot type.
Arguments
customer- Required. Obfuscated customer ID prefixed with “customers/C” or “customers/my_customer”.
Sourcepub fn reports_count_devices_per_release_channel(
&self,
customer: &str,
) -> CustomerReportCountDevicesPerReleaseChannelCall<'a, C>
pub fn reports_count_devices_per_release_channel( &self, customer: &str, ) -> CustomerReportCountDevicesPerReleaseChannelCall<'a, C>
Create a builder to help you perform the following task:
Get a count of devices per channel.
Arguments
customer- Required. Obfuscated customer ID prefixed with “customers/C” or “customers/my_customer”.
Sourcepub fn reports_count_installed_apps(
&self,
customer: &str,
) -> CustomerReportCountInstalledAppCall<'a, C>
pub fn reports_count_installed_apps( &self, customer: &str, ) -> CustomerReportCountInstalledAppCall<'a, C>
Create a builder to help you perform the following task:
Generate report of app installations.
Arguments
customer- Required. Customer id or “my_customer” to use the customer associated to the account making the request.
Sourcepub fn reports_count_print_jobs_by_printer(
&self,
customer: &str,
) -> CustomerReportCountPrintJobsByPrinterCall<'a, C>
pub fn reports_count_print_jobs_by_printer( &self, customer: &str, ) -> CustomerReportCountPrintJobsByPrinterCall<'a, C>
Create a builder to help you perform the following task:
Get a summary of printing done by each printer.
Arguments
customer- Required. Customer ID prefixed with “customers/” or “customers/my_customer” to use the customer associated to the account making the request.
Sourcepub fn reports_count_print_jobs_by_user(
&self,
customer: &str,
) -> CustomerReportCountPrintJobsByUserCall<'a, C>
pub fn reports_count_print_jobs_by_user( &self, customer: &str, ) -> CustomerReportCountPrintJobsByUserCall<'a, C>
Create a builder to help you perform the following task:
Get a summary of printing done by each user.
Arguments
customer- Required. Customer ID prefixed with “customers/” or “customers/my_customer” to use the customer associated to the account making the request.
Sourcepub fn reports_enumerate_print_jobs(
&self,
customer: &str,
) -> CustomerReportEnumeratePrintJobCall<'a, C>
pub fn reports_enumerate_print_jobs( &self, customer: &str, ) -> CustomerReportEnumeratePrintJobCall<'a, C>
Create a builder to help you perform the following task:
Get a list of print jobs.
Arguments
customer- Required. Customer ID prefixed with “customers/” or “customers/my_customer” to use the customer associated to the account making the request.
Sourcepub fn reports_find_installed_app_devices(
&self,
customer: &str,
) -> CustomerReportFindInstalledAppDeviceCall<'a, C>
pub fn reports_find_installed_app_devices( &self, customer: &str, ) -> CustomerReportFindInstalledAppDeviceCall<'a, C>
Create a builder to help you perform the following task:
Generate report of managed Chrome browser devices that have a specified app installed.
Arguments
customer- Required. Customer id or “my_customer” to use the customer associated to the account making the request.
Sourcepub fn telemetry_devices_get(
&self,
name: &str,
) -> CustomerTelemetryDeviceGetCall<'a, C>
pub fn telemetry_devices_get( &self, name: &str, ) -> CustomerTelemetryDeviceGetCall<'a, C>
Create a builder to help you perform the following task:
Get telemetry device.
Arguments
name- Required. Name of theTelemetryDeviceto return.
Sourcepub fn telemetry_devices_list(
&self,
parent: &str,
) -> CustomerTelemetryDeviceListCall<'a, C>
pub fn telemetry_devices_list( &self, parent: &str, ) -> CustomerTelemetryDeviceListCall<'a, C>
Create a builder to help you perform the following task:
List all telemetry devices.
Arguments
parent- Required. Customer id or “my_customer” to use the customer associated to the account making the request.
Sourcepub fn telemetry_events_list(
&self,
parent: &str,
) -> CustomerTelemetryEventListCall<'a, C>
pub fn telemetry_events_list( &self, parent: &str, ) -> CustomerTelemetryEventListCall<'a, C>
Create a builder to help you perform the following task:
List telemetry events.
Arguments
parent- Required. Customer id or “my_customer” to use the customer associated to the account making the request.
Sourcepub fn telemetry_notification_configs_create(
&self,
request: GoogleChromeManagementV1TelemetryNotificationConfig,
parent: &str,
) -> CustomerTelemetryNotificationConfigCreateCall<'a, C>
pub fn telemetry_notification_configs_create( &self, request: GoogleChromeManagementV1TelemetryNotificationConfig, parent: &str, ) -> CustomerTelemetryNotificationConfigCreateCall<'a, C>
Create a builder to help you perform the following task:
Create a telemetry notification config.
Arguments
request- No description provided.parent- Required. The parent resource where this notification config will be created. Format:customers/{customer}
Sourcepub fn telemetry_notification_configs_delete(
&self,
name: &str,
) -> CustomerTelemetryNotificationConfigDeleteCall<'a, C>
pub fn telemetry_notification_configs_delete( &self, name: &str, ) -> CustomerTelemetryNotificationConfigDeleteCall<'a, C>
Create a builder to help you perform the following task:
Delete a telemetry notification config.
Arguments
name- Required. The name of the notification config to delete. Format:customers/{customer}/telemetry/notificationConfigs/{notification_config}
Sourcepub fn telemetry_notification_configs_list(
&self,
parent: &str,
) -> CustomerTelemetryNotificationConfigListCall<'a, C>
pub fn telemetry_notification_configs_list( &self, parent: &str, ) -> CustomerTelemetryNotificationConfigListCall<'a, C>
Create a builder to help you perform the following task:
List all telemetry notification configs.
Arguments
parent- Required. The parent which owns the notification configs.
Sourcepub fn telemetry_users_get(
&self,
name: &str,
) -> CustomerTelemetryUserGetCall<'a, C>
pub fn telemetry_users_get( &self, name: &str, ) -> CustomerTelemetryUserGetCall<'a, C>
Create a builder to help you perform the following task:
Get telemetry user.
Arguments
name- Required. Name of theTelemetryUserto return.
Sourcepub fn telemetry_users_list(
&self,
parent: &str,
) -> CustomerTelemetryUserListCall<'a, C>
pub fn telemetry_users_list( &self, parent: &str, ) -> CustomerTelemetryUserListCall<'a, C>
Create a builder to help you perform the following task:
List all telemetry users.
Arguments
parent- Required. Customer id or “my_customer” to use the customer associated to the account making the request.
Sourcepub fn third_party_profile_users_move(
&self,
request: GoogleChromeManagementVersionsV1MoveThirdPartyProfileUserRequest,
name: &str,
) -> CustomerThirdPartyProfileUserMoveCall<'a, C>
pub fn third_party_profile_users_move( &self, request: GoogleChromeManagementVersionsV1MoveThirdPartyProfileUserRequest, name: &str, ) -> CustomerThirdPartyProfileUserMoveCall<'a, C>
Create a builder to help you perform the following task:
Moves a third party chrome profile user to a destination OU. All profiles associated to that user will be moved to the destination OU.
Arguments
request- No description provided.name- Required. Format: customers/{customer_id}/thirdPartyProfileUsers/{third_party_profile_user_id}